/*    patchlevel.h
 *
 *    Copyright (C) 1993, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002,
 *    2003, 2004, 2005, 2006, 2007, 2008, 2009, by Larry Wall and others
 *
 *    You may distribute under the terms of either the GNU General Public
 *    License or the Artistic License, as specified in the README file.
 *
 */

#ifndef __PATCHLEVEL_H_INCLUDED__

/* do not adjust the whitespace! Configure expects the numbers to be
 * exactly on the third column */

#define PERL_REVISION	5		/* age */
#define PERL_VERSION	30		/* epoch */
#define PERL_SUBVERSION	1		/* generation */

/* The following numbers describe the earliest compatible version of
   Perl ("compatibility" here being defined as sufficient binary/API
   compatibility to run XS code built with the older version).
   Normally this should not change across maintenance releases.

   Note that this only refers to an out-of-the-box build.  Many non-default
   options such as usemultiplicity tend to break binary compatibility
   more often.

   This is used by Configure et al to figure out
   PERL_INC_VERSION_LIST, which lists version libraries
   to include in @INC.  See INSTALL for how this works.

   Porting/bump-perl-version will automatically set these to the version of perl
   to be released for blead releases, and to 5.X.0 for maint releases. Manually
   changing them should not be necessary.
*/
#define PERL_API_REVISION	5
#define PERL_API_VERSION	30
#define PERL_API_SUBVERSION	0
/*
   XXX Note:  The selection of non-default Configure options, such
   as -Duselonglong may invalidate these settings.  Currently, Configure
   does not adequately test for this.   A.D.  Jan 13, 2000
*/

#define __PATCHLEVEL_H_INCLUDED__
#endif

/*
	local_patches -- list of locally applied less-than-subversion patches.
	If you're distributing such a patch, please give it a name and a
	one-line description, placed just before the last NULL in the array
	below.  If your patch fixes a bug in the perlbug database, please
	mention the bugid.  If your patch *IS* dependent on a prior patch,
	please place your applied patch line after its dependencies. This
	will help tracking of patch dependencies.

	Please either use 'diff --unified=0' if your diff supports
	that or edit the hunk of the diff output which adds your patch
	to this list, to remove context lines which would give patch
	problems. For instance, if the original context diff is

	   *** patchlevel.h.orig	<date here>
	   --- patchlevel.h	<date here>
	   *** 38,43 ***
	   --- 38,44 ---
	     	,"FOO1235 - some patch"
	     	,"BAR3141 - another patch"
	     	,"BAZ2718 - and another patch"
	   + 	,"MINE001 - my new patch"
	     	,NULL
	     };

	please change it to
	   *** patchlevel.h.orig	<date here>
	   --- patchlevel.h	<date here>
	   *** 41,43 ***
	   --- 41,44 ---
	   + 	,"MINE001 - my new patch"
	     	,NULL
	     };

	(Note changes to line numbers as well as removal of context lines.)
	This will prevent patch from choking if someone has previously
	applied different patches than you.

        History has shown that nobody distributes patches that also
        modify patchlevel.h. Do it yourself. The following perl
        program can be used to add a comment to patchlevel.h:

#!perl
die "Usage: perl -x patchlevel.h comment ..." unless @ARGV;
open PLIN, "<", "patchlevel.h" or die "Couldn't open patchlevel.h : $!";
open PLOUT, ">", "patchlevel.new" or die "Couldn't write on patchlevel.new : $!";
my $seen=0;
while (<PLIN>) {
    if (/\t,NULL/ and $seen) {
       while (my $c = shift @ARGV){
	    $c =~ s|\\|\\\\|g;
	    $c =~ s|"|\\"|g;
            print PLOUT qq{\t,"$c"\n};
       }
    }
    $seen++ if /local_patches\[\]/;
    print PLOUT;
}
close PLOUT or die "Couldn't close filehandle writing to patchlevel.new : $!";
close PLIN or die "Couldn't close filehandle reading from patchlevel.h : $!";
close DATA; # needed to allow unlink to work win32.
unlink "patchlevel.bak" or warn "Couldn't unlink patchlevel.bak : $!"
  if -e "patchlevel.bak";
rename "patchlevel.h", "patchlevel.bak" or
  die "Couldn't rename patchlevel.h to patchlevel.bak : $!";
rename "patchlevel.new", "patchlevel.h" or
  die "Couldn't rename patchlevel.new to patchlevel.h : $!";
__END__

Please keep empty lines below so that context diffs of this file do
not ever collect the lines belonging to local_patches() into the same
hunk.

 */

#if !defined(PERL_PATCHLEVEL_H_IMPLICIT) && !defined(LOCAL_PATCH_COUNT)
#  if defined(PERL_IS_MINIPERL)
#    define PERL_PATCHNUM "UNKNOWN-miniperl"
#    define PERL_GIT_UNPUSHED_COMMITS /*leave-this-comment*/
#  elif defined(PERL_MICRO)
#    define PERL_PATCHNUM "UNKNOWN-microperl"
#    define PERL_GIT_UNPUSHED_COMMITS /*leave-this-comment*/
#  else
#include "git_version.h"
#  endif
static const char * const local_patches[] = {
	NULL
#ifdef PERL_GIT_UNCOMMITTED_CHANGES
	,"uncommitted-changes"
#endif
	PERL_GIT_UNPUSHED_COMMITS    	/* do not remove this line */
	,"Fedora Patch1: Removes date check, Fedora/RHEL specific"
	,"Fedora Patch2: support for libdir64"
	,"Fedora Patch3: use libresolv instead of libbind"
	,"Fedora Patch4: USE_MM_LD_RUN_PATH"
	,"Fedora Patch5: Provide MM::maybe_command independently (bug #1129443)"
	,"Fedora Patch6: Dont run one io test due to random builder failures"
	,"Fedora Patch8: Define SONAME for libperl.so"
	,"Fedora Patch9: Install libperl.so to -Dshrpdir value"
	,"Fedora Patch10: Make *DBM_File desctructors thread-safe (RT#61912)"
	,"Fedora Patch11: Replace EU::MakeMaker dependency with EU::MM::Utils in IPC::Cmd (bug #1129443)"
	,"Fedora Patch12: Link XS modules to pthread library to fix linking with -z defs"
	,"Fedora Patch13: Pass the correct CFLAGS to dtrace"
	,"Fedora Patch15: Do not panic when outputting a warning (RT#134059)"
	,"Fedora Patch16: Fix memory handling when parsing string literals"
	,"Fedora Patch17: Fix an undefined behavior in shifting IV variables"
	,"Fedora Patch18: Fix an undefined behavior in shifting IV variables"
	,"Fedora Patch19: Fix an undefined behavior in shifting IV variables"
	,"Fedora Patch20: Fix stacking file test operators (CPAN RT#127073)"
	,"Fedora Patch21: Fix a crash in SIGALARM handler when waiting on a child process to be closed (RT#122112)"
	,"Fedora Patch22: Fix a crash in SIGALARM handler when waiting on a child process to be closed (RT#122112)"
	,"Fedora Patch23: Fix a crash in SIGALARM handler when waiting on a child process to be closed (RT#122112)"
	,"Fedora Patch25: Fix a crash with a negative precision in sprintf function (RT#134008)"
	,"Fedora Patch27: Prevent from wrapping a width in a numeric format string (RT#133913)"
	,"Fedora Patch28: Fix subroutine protypes to track reference aliases (RT#134072)"
	,"Fedora Patch30: Fix changing packet destination sent from a UDP IO::Socket object (RT#133936)"
	,"Fedora Patch31: Fix changing packet destination sent from a UDP IO::Socket object (RT#133936)"
	,"Fedora Patch32: Fix changing packet destination sent from a UDP IO::Socket object (RT#133936)"
	,"Fedora Patch37: Fix %{^CAPTURE_ALL} to be an alias for %- variable (RT#131867)"
	,"Fedora Patch38: Fix %{^CAPTURE} value when used after @{^CAPTURE} (RT#134193)"
	,"Fedora Patch39: Fix %{^CAPTURE} value when used after @{^CAPTURE} (RT#134193)"
	,"Fedora Patch40: Fix a test for a crash in SIGALARM handler when waiting on a child process to be closed (RT#122112)"
	,"Fedora Patch41: Fix a crash on an uninitialized warning when processing a multideref node (RT#134275)"
	,"Fedora Patch42: Preserve append mode when opening anonymous files (RT#134221)"
	,"Fedora Patch43: Preserve append mode when opening anonymous files (RT#134221)"
	,"Fedora Patch44: Preserve append mode when opening anonymous files (RT#134221)"
	,"Fedora Patch45: Fix propagating non-string variables in an exception value (RT#134291)"
	,"Fedora Patch46: Include trailing zero in scalars holding trie data (RT#134207)"
	,"Fedora Patch48: Fix a use after free in debugging output of a collation"
	,"Fedora Patch49: Fix a NULL pointer dereference in PerlIOVia_pushed()"
	,"Fedora Patch50: Fix a crash when setting $@ on unwinding a call stack (RT#134266)"
	,"Fedora Patch51: Fix parsing a denominator when parsing a Unicode property name"
	,"Fedora Patch52: Fix a documentation about a future API change"
	,"Fedora Patch53: Do not run File-Find tests in parallel"
	,"Fedora Patch54: Fix parsing a Unicode property name when compiling a regular expression"
	,"Fedora Patch56: Do not interpret 0x and 0b prefixes when numifying strings (RT#134230)"
	,"Fedora Patch58: Fix a buffer overflow when compiling a regular expression with many branches (RT#134329)"
	,"Fedora Patch59: Correct a misspelling in perlrebackslash documentation (RT#134395)"
	,"Fedora Patch61: Fix a detection for futimes (RT#134432)"
	,"Fedora Patch62: Fix a detection for futimes (RT#134432)"
	,"Fedora Patch63: Fix overloading for binary and octal floats (RT#125557)"
	,"Fedora Patch64: Fix handling undefined array members in Dumpvalue (RT#134441)"
	,"Fedora Patch65: Fix taint mode documentation regarding @INC"
	,"Fedora Patch66: Fix taint mode documentation regarding @INC"
	,"Fedora Patch67: Fix handling a layer argument in Tie::StdHandle::BINMODE() (RT#132475)"
	,"Fedora Patch68: Fix an unintended upgrade to UTF-8 in the middle of a transliteration"
	,"Fedora Patch69: Fix an unintended upgrade to UTF-8 in the middle of a transliteration"
	,"Fedora Patch70: Fix a race in File::stat() tests (GH#17234)"
	,"Fedora Patch71: Fix a buffer overread when parsing a number (GH#17279)"
	,"Fedora Patch72: Fix GCC 10 version detection (GH#17295)"
	,"Fedora Patch73: Fix a memory leak when compiling a regular expression with a non-word class (GH#17218)"
	,"Fedora Patch74: Fix CVE-2020-10543 (an integer overflow from nested regex quantifiers)"
	,"Fedora Patch75: Fix CVE-2020-10878 (a corruption of a state of a compiled regular expression due to an integer overflow)"
	,"Fedora Patch76: Fix CVE-2020-10878 (a corruption of a state of a compiled regular expression due to an integer overflow)"
	,"Fedora Patch77: Fix CVE-2020-12723 (a corruption of a state of a compiled regular expression due to recursive calls)"
	,"Fedora Patch200: Link XS modules to libperl.so with EU::CBuilder on Linux"
	,"Fedora Patch201: Link XS modules to libperl.so with EU::MM on Linux"
	,NULL
};



/* Initial space prevents this variable from being inserted in config.sh  */
#  define	LOCAL_PATCH_COUNT	\
	((int)(C_ARRAY_LENGTH(local_patches)-2))

/* the old terms of reference, add them only when explicitly included */
#define PATCHLEVEL		PERL_VERSION
#undef  SUBVERSION		/* OS/390 has a SUBVERSION in a system header */
#define SUBVERSION		PERL_SUBVERSION
#endif
